#include <QApplication>
#include <QSettings>
#include <QMdiArea>
#include <QMdiSubWindow>
#include <QPushButton>
#include "remtimer.h"

class TimerSheet: public QMdiArea {
  Q_OBJECT
public:
  TimerSheet() {
	setWindowTitle( "remtimer mdi" );

	QSettings settings;
	if ( settings.contains("geom") ) {
		restoreGeometry( settings.value("geom").toByteArray() );

		int count = settings.beginReadArray("timers");
		for ( int i = 0; i < count; i++ ) {
			auto *timer = new RemainingTimer();

			settings.setArrayIndex( i );
			timer->descLE->setText( settings.value("desc").toString() );
			timer->destTime->setDateTime( settings.value("targ").toDateTime() );

			auto *w = newTimer( timer );
			w->move( settings.value("pos").toPoint() );
		}
		settings.endArray();
	}
	else {
		resize(300, 400);
		newTimer();
	}

	b = new QPushButton( "+", this );
	b->setMaximumWidth( 20 );
	b->show();

	connect( b, SIGNAL(clicked()), SLOT(newTimer()) );
  }
  ~TimerSheet() {
	QSettings settings;
	settings.setValue( "geom", saveGeometry() );

	settings.beginWriteArray("timers");
	int idx = 0;
	foreach ( auto w, subWindowList() ) {
		auto timer = (RemainingTimer*)w->widget();
		settings.setArrayIndex(idx++);
		settings.setValue("desc", timer->descLE->text() );
		settings.setValue("targ", timer->destTime->dateTime() );
		settings.setValue("pos", w->pos() );
	}
	settings.endArray();
  }

protected:
  QPushButton *b;
  void resizeEvent( QResizeEvent *e ) {
	QMdiArea::resizeEvent( e );
	b->move( width() - b->width(), 0 );
  }
  QMdiSubWindow *newTimer( RemainingTimer *timer ) {
	auto *w = addSubWindow( timer );
	w->setAttribute( Qt::WA_DeleteOnClose );
	w->show();
	return w;
  }
protected slots:
  void newTimer() { newTimer( new RemainingTimer() ); }
};

#include "main.moc"

int main( int argc, char **argv ) {
  QApplication qa( argc, argv );
  qa.setOrganizationName("vr5");
  qa.setApplicationName("remtimer-mdi");

  if ( !QSettings().value("systemstyle", false).toBool() )
	qa.setStyle("windows");

  auto *mdi = new TimerSheet;
  mdi->setAttribute( Qt::WA_DeleteOnClose );
  mdi->show();

  return qa.exec();
}
